@@ -99,7 +99,7 @@ class Pxlapi():
         return await self.get_img('lego', body)
 
 
-    async def snapchat(self, filter:str, images:list, filters:list=None:
+    async def snapchat(self, filter:str, images:list, filters:list=None):
         if not filter.lower() in self.filters:
             if self.stop_on_error:
                 raise InvalidFilter(f'Flag {filter.lower()} not a valid flag')
